@@ -25,7 +25,8 @@ import ConfigParser
 
 from TrayIcon import TrayIcon
 
-from more import get_sid, get_view_params, _print, get_icon, get_system_rgb
+from more import get_sid, get_view_params, _print, get_icon, get_system_rgb, \
+    dpivalue
     
 from MainClass import ApiClient
 from calculate.consolegui.datavars import DataVarsGui
@@ -316,7 +317,7 @@ class ToolTabWidget(qt.QTabWidget):
             if d_size.height() < 768:
                 self.resize(900,560)
             else:
-                self.resize(900, 700)
+                self.resize(dpivalue(900), dpivalue(700))
         self.setMinimumHeight(100)
         self.setMinimumWidth(500)
 
