@@ -14,8 +14,8 @@
 #  See the License for the specific language governing permissions and
 #  limitations under the License.
 
-from PySide import QtGui, QtCore
-from more import LabelWordWrap, _print, get_system_rgb, ParameterWindow
+from calculate.consolegui import qt
+from more import LabelWordWrap, _print, get_system_rgb, ParameterWindow, dpivalue
 
 DEBUG_LEVEL = 0
 
@@ -27,26 +27,26 @@ def debug(level, *args):
         print
 
 
-class MethodNameWgt(QtGui.QWidget):
+class MethodNameWgt(qt.QWidget):
     def __init__(self, parent, ClientObj):
-        QtGui.QWidget.__init__(self, parent)
+        qt.QWidget.__init__(self, parent)
         self._parent = parent
         self.ClientObj = ClientObj
 
         # Set style
-        self.setAttribute(QtCore.Qt.WA_StyledBackground)
+        self.setAttribute(qt.Qt.WA_StyledBackground)
         self.setObjectName('ControlButton')
         self.setStyleSheet("QWidget#ControlButton "
                            "{background-color: qlineargradient(x1: 0, y1: 0, x2: 0, y2: 1,"
                            "stop: 0 #111111, stop: 0.95 #777777, stop: 1 #666666);}")
 
-        self.hlayout = QtGui.QHBoxLayout(self)
-        self.hlayout.setAlignment(QtCore.Qt.AlignLeft | QtCore.Qt.AlignVCenter)
+        self.hlayout = qt.QHBoxLayout(self)
+        self.hlayout.setAlignment(qt.Qt.AlignLeft | qt.Qt.AlignVCenter)
         self.hlayout.setContentsMargins(28, 0, 0, 0)
         self.hlayout.setSpacing(0)
 
-        self.meth_name = QtGui.QLabel('Method Name', self)
-        #        self.meth_name.setAlignment(QtCore.Qt.AlignLeft)
+        self.meth_name = qt.QLabel('Method Name', self)
+        #        self.meth_name.setAlignment(qt.Qt.AlignLeft)
         self.meth_name.setStyleSheet("font-size: 16px;"
                                      "font: bold;"
                                      "color: white;");
@@ -102,35 +102,35 @@ class MethodNameWgt(QtGui.QWidget):
 #                "stop: 0 #222222, stop: 1 #9797A0);}" + \
 #                self.button_hover_style + self.button_pressed_style)
 
-class ControlButtonWgt(QtGui.QWidget):
+class ControlButtonWgt(qt.QWidget):
     def __init__(self, parent, ClientObj):
-        QtGui.QWidget.__init__(self, parent)
+        qt.QWidget.__init__(self, parent)
         self._parent = parent
         self.ClientObj = ClientObj
 
         # Set style
-        self.setAttribute(QtCore.Qt.WA_StyledBackground)
+        self.setAttribute(qt.Qt.WA_StyledBackground)
         self.setObjectName('ControlButton')
         self.setStyleSheet("QWidget#ControlButton "
                            "{background-color: %s;}"%
                            get_system_rgb(self, ParameterWindow))
 
-        self.main_layout = QtGui.QVBoxLayout(self)
+        self.main_layout = qt.QVBoxLayout(self)
         self.main_layout.setContentsMargins(28, 8, 0, 28)
         self.question_label = LabelWordWrap("")
         # self.question_label.hide()
         self.main_layout.addWidget(self.question_label)
 
-        self.hlayout = QtGui.QHBoxLayout()
-        self.hlayout.setAlignment(QtCore.Qt.AlignLeft | QtCore.Qt.AlignVCenter)
+        self.hlayout = qt.QHBoxLayout()
+        self.hlayout.setAlignment(qt.Qt.AlignLeft | qt.Qt.AlignVCenter)
         self.hlayout.setContentsMargins(0, 0, 28, 0)
         self.hlayout.setSpacing(0)
-        self.main_layout.addItem(QtGui.QSpacerItem(
-            0, 0, QtGui.QSizePolicy.Expanding, QtGui.QSizePolicy.Expanding))
+        self.main_layout.addItem(qt.QSpacerItem(
+            0, 0, qt.QSizePolicy.Expanding, qt.QSizePolicy.Expanding))
         self.main_layout.addLayout(self.hlayout)
 
         # self.setLayout(self.hlayout)
-        self.setFixedHeight(90)
+        self.setFixedHeight(dpivalue(90))
         self.hide()
         self.confirmWgt = None
         self.break_button = None
@@ -179,15 +179,15 @@ class ControlButtonWgt(QtGui.QWidget):
         self.hide()
 
     def add_custom_button(self, Group, x, y, brief=False,
-                            next_button_text=None):
+                            next_button_text=""):
         self.del_button()
         buttons = self._parent.MainFrameWgt.buttons
-        self.button_widget = QtGui.QWidget(self)
-        end_layout = QtGui.QHBoxLayout(self.button_widget)
+        self.button_widget = qt.QWidget(self)
+        end_layout = qt.QHBoxLayout(self.button_widget)
         end_layout.setContentsMargins(0, 0, 0, 0)
         end_layout.setSpacing(10)
-        end_layout.addItem(QtGui.QSpacerItem(
-            0, 0, QtGui.QSizePolicy.Expanding, QtGui.QSizePolicy.Maximum))
+        end_layout.addItem(qt.QSpacerItem(
+            0, 0, qt.QSizePolicy.Expanding, qt.QSizePolicy.Maximum))
 
         self.customs = []
         self.add_cancel_button(end_layout, Group, brief, next_button_text)
@@ -198,34 +198,34 @@ class ControlButtonWgt(QtGui.QWidget):
                 self.add_next_button(end_layout, Group, brief, next_button_text)
                 has_next = True
             else:
-                button = QtGui.QPushButton(self)
+                button = qt.QPushButton(self)
                 self.customs.append(button)
                 button.setText(field.label.decode('utf-8'))
                 button.clicked.connect(self.button_disabled)
                 button.clicked.connect(callback)
                 button.setMinimumWidth(62)
-                button.setFixedHeight(32)
+                button.setFixedHeight(dpivalue(32))
                 if field.guitype == "readonly":
                     button.setDisabled(True)
                 end_layout.addWidget(button)
         if not has_next and button:
-            button.setShortcut(QtGui.QKeySequence(QtCore.Qt.Key_Return))
-            button.setShortcut(QtGui.QKeySequence(QtCore.Qt.Key_Enter))
+            button.setShortcut(qt.QKeySequence(qt.Qt.Key_Return))
+            button.setShortcut(qt.QKeySequence(qt.Qt.Key_Enter))
             self.default_button = button
 
         self.hlayout.addWidget(self.button_widget)
 
     def add_standart_button(self, Group, x, y, brief=False, \
-                            next_button_text=None):
+                            next_button_text=""):
         self.del_button()
         main_frame = self._parent.MainFrameWgt
         # add 1 (or 2) button ok (next) [and previous]
-        self.button_widget = QtGui.QWidget(self)
-        end_layout = QtGui.QHBoxLayout(self.button_widget)
+        self.button_widget = qt.QWidget(self)
+        end_layout = qt.QHBoxLayout(self.button_widget)
         end_layout.setContentsMargins(0, 0, 0, 0)
         end_layout.setSpacing(10)
-        end_layout.addItem(QtGui.QSpacerItem(
-            0, 0, QtGui.QSizePolicy.Expanding, QtGui.QSizePolicy.Maximum))
+        end_layout.addItem(qt.QSpacerItem(
+            0, 0, qt.QSizePolicy.Expanding, qt.QSizePolicy.Maximum))
 
         self.add_cancel_button(end_layout, Group, brief, next_button_text)
         self.add_prev_button(end_layout, Group, brief, next_button_text)
@@ -236,10 +236,10 @@ class ControlButtonWgt(QtGui.QWidget):
         return x
 
     def add_cancel_button(self, end_layout, Group, brief=False,
-                        next_button_text=None):
+                        next_button_text=""):
         # создать кнопку отмена
         main_frame = self._parent.MainFrameWgt
-        self.cancel_button = QtGui.QPushButton(self)
+        self.cancel_button = qt.QPushButton(self)
         if main_frame.has_errors:
             self.cancel_button.setText(_('Close').decode('utf-8'))
         else:
@@ -252,48 +252,48 @@ class ControlButtonWgt(QtGui.QWidget):
             lambda:main_frame.clear_cache_info(method_name))
 
         self.cancel_button.setMinimumWidth(62)
-        self.cancel_button.setFixedHeight(32)
+        self.cancel_button.setFixedHeight(dpivalue(32))
         if self.button_widget:
             end_layout.addWidget(self.cancel_button)
 
         if main_frame.has_errors:
             self.cancel_button.setShortcut(
-                QtGui.QKeySequence(QtCore.Qt.Key_Return))
+                qt.QKeySequence(qt.Qt.Key_Return))
             self.cancel_button.setShortcut(
-                QtGui.QKeySequence(QtCore.Qt.Key_Enter))
+                qt.QKeySequence(qt.Qt.Key_Enter))
             self.default_button = self.cancel_button
         else:
             self.cancel_button.setShortcut(
-                QtGui.QKeySequence(QtCore.Qt.Key_Escape))
+                qt.QKeySequence(qt.Qt.Key_Escape))
 
 
     def add_prev_button(self, end_layout, Group, brief=False,
-                        next_button_text=None):
+                        next_button_text=""):
         # создать кнопку предыдущий
         main_frame = self._parent.MainFrameWgt
         if (self.ClientObj.param_objects[main_frame.method_name]['step'] != 0
             and main_frame.mutable):
             debug(10, "CREATE PREV BUTTON")
-            self.prev_button = QtGui.QPushButton(self)
+            self.prev_button = qt.QPushButton(self)
             self.prev_button.setText(Group.prevlabel or _('Previous'))
 
             self.prev_button.clicked.connect(self.button_disabled)
             self.prev_button.clicked.connect(main_frame.button_call_view(-1))
             #            self.prev_button.clicked.connect(self.button_enabled)
             self.prev_button.setMinimumWidth(62)
-            self.prev_button.setFixedHeight(32)
+            self.prev_button.setFixedHeight(dpivalue(32))
             if self.button_widget:
                 end_layout.addWidget(self.prev_button)
 
     def add_next_button(self, end_layout, Group, brief=False,
-                            next_button_text=None):
+                            next_button_text=""):
         # если текущая страница - brief
         # если это последний шаг, но метод без brief
         main_frame = self._parent.MainFrameWgt
         if (brief or main_frame.view.groups.GroupField[-1].last and
             not main_frame.hasBrief()):
             debug(10, "CREATE PERFORM BUTTON")
-            self.next_button = QtGui.QPushButton(self)
+            self.next_button = qt.QPushButton(self)
             if next_button_text and brief:
                 self.next_button.setText(next_button_text)
             else:
@@ -308,7 +308,7 @@ class ControlButtonWgt(QtGui.QWidget):
                 end_layout.addWidget(self.next_button)
         else:
             debug(10, "CREATE NEXT BUTTON")
-            self.next_button = QtGui.QPushButton(self)
+            self.next_button = qt.QPushButton(self)
             self.next_button.setText(Group.nextlabel or _("Next"))
 
             self.next_button.clicked.connect(self.button_disabled)
@@ -321,9 +321,9 @@ class ControlButtonWgt(QtGui.QWidget):
                 end_layout.addWidget(self.next_button)
 
         self.next_button.setMinimumWidth(64)
-        self.next_button.setFixedHeight(32)
-        self.next_button.setShortcut(QtGui.QKeySequence(QtCore.Qt.Key_Return))
-        self.next_button.setShortcut(QtGui.QKeySequence(QtCore.Qt.Key_Enter))
+        self.next_button.setFixedHeight(dpivalue(32))
+        self.next_button.setShortcut(qt.QKeySequence(qt.Qt.Key_Return))
+        self.next_button.setShortcut(qt.QKeySequence(qt.Qt.Key_Enter))
         self.default_button = self.next_button
 
     def del_button(self):
@@ -350,18 +350,18 @@ class ControlButtonWgt(QtGui.QWidget):
     def pre_add_button(self):
         self.del_button()
         # add 1 (or 2) button ok (next) [and previous]
-        self.button_widget = QtGui.QWidget(self)
-        end_layout = QtGui.QHBoxLayout(self.button_widget)
+        self.button_widget = qt.QWidget(self)
+        end_layout = qt.QHBoxLayout(self.button_widget)
         end_layout.setContentsMargins(0, 0, 0, 0)
         end_layout.setSpacing(0)
-        end_layout.addItem(QtGui.QSpacerItem(0, 0, \
-                                             QtGui.QSizePolicy.Expanding,
-                                             QtGui.QSizePolicy.Maximum))
+        end_layout.addItem(qt.QSpacerItem(0, 0, \
+                                             qt.QSizePolicy.Expanding,
+                                             qt.QSizePolicy.Maximum))
         return end_layout
 
     def add_clear_cache_button(self, pid=None):
         end_layout = self.pre_add_button()
-        self.clear_proc_cache_button = QtGui.QPushButton(_('Close'), self)
+        self.clear_proc_cache_button = qt.QPushButton(_('Close'), self)
         self.default_button = self.clear_proc_cache_button
         self.ClientObj._parent.user_changed_flag = False
         if pid:
@@ -370,7 +370,7 @@ class ControlButtonWgt(QtGui.QWidget):
         else:
             self.clear_proc_cache_button.clicked.connect(self._parent.back)
         self.clear_proc_cache_button.setMinimumWidth(64)
-        self.clear_proc_cache_button.setFixedHeight(32)
+        self.clear_proc_cache_button.setFixedHeight(dpivalue(32))
         end_layout.addWidget(self.clear_proc_cache_button)
         self.hlayout.addWidget(self.button_widget)
 
@@ -449,11 +449,11 @@ class ControlButtonWgt(QtGui.QWidget):
         self.ClientObj.app.processEvents()
 
     def keyPressEvent(self, e):
-        if e.key() == QtCore.Qt.Key_Return:
+        if e.key() == qt.Qt.Key_Return:
             if self.default_button:
                 self.default_button.click()
-        elif e.key() == QtCore.Qt.Key_Escape:
+        elif e.key() == qt.Qt.Key_Escape:
             if self.cancel_button:
                 self.cancel_button.click()
         else:
-            QtGui.QWidget.keyPressEvent(self, e)
+            qt.QWidget.keyPressEvent(self, e)
