@@ -18,7 +18,7 @@ from calculate.consolegui import qt
 
 from more import ButtonMenu, FlowLayout, get_sid, ClientServiceThread, \
                  get_view_params, show_msg, client_list_methods, get_system_rgb, \
-                 get_icon
+                 get_icon, dpivalue
 
 class DisplayMethod(qt.QWidget):
     def __init__(self, parent, ClientObj):
@@ -42,6 +42,10 @@ class DisplayMethod(qt.QWidget):
         # set new Title
         self.ClientObj._parent.setWindowTitle(self.ClientObj.Name)
 
+
+        groupbox_style = \
+            "QGroupBox { padding-top: %dpx; padding-left: 10px;}" % dpivalue(24)
+
         # transform a list into the dictionary {'group': [methods], ...}
         guiMethods = {}
         if type(results) == int:
@@ -69,11 +73,10 @@ class DisplayMethod(qt.QWidget):
                 group_name = group.split('.')[0].encode('utf-8')
                 sub_group = group.split('.')[1].encode('utf-8')
                 if not self.groupbox_dict.has_key(group_name):
-                    self.groupbox_dict[group_name] = \
-                              qt.QGroupBox(group_name.decode('utf-8'), self)
-
-                    self.groupbox_dict[group_name].setAlignment \
-                                                        (qt.Qt.AlignLeft)
+                    gb = qt.QGroupBox(group_name.decode('utf-8'), self)
+                    gb.setStyleSheet(groupbox_style)
+                    gb.setAlignment(qt.Qt.AlignLeft)
+                    self.groupbox_dict[group_name] = gb
 
                 if not self.layout_dict.has_key(group_name):
                     self.layout_dict[group_name] = \
@@ -105,9 +108,10 @@ class DisplayMethod(qt.QWidget):
                 continue
 
             if not self.groupbox_dict.has_key(group):
-                self.groupbox_dict[group] = \
-                                qt.QGroupBox(group, self)
-                self.groupbox_dict[group].setAlignment(qt.Qt.AlignLeft)
+                gb = qt.QGroupBox(group, self)
+                gb.setStyleSheet(groupbox_style)
+                self.groupbox_dict[group] = gb
+                gb.setAlignment(qt.Qt.AlignLeft)
 
             if not self.layout_dict.has_key(group):
                 self.layout_dict[group] = FlowLayout(self.groupbox_dict[group])
